"use client";

import BlurFade from "@/components/ui/blur-fade";
import {
	Form,
	FormControl,
	FormField,
	FormItem,
	FormMessage,
} from "@/components/ui/form";
import { Label } from "@/components/ui/label";
import { PlaceholdersAndVanishInput } from "@/components/ui/placeholders-and-vanish-input";
import { Locale } from "@/i18n/routing";
import { usePoolRequestInfo } from "@/servers/data/use-pool-request-info";
import { zodResolver } from "@hookform/resolvers/zod";
import { useTranslations } from "next-intl";
import { useEffect } from "react";
import { useForm } from "react-hook-form";
import * as z from "zod";

type RequestFieldVisitFormValues = {
	fullName: string;
	email: string;
	phone: string;
	address: string;
	message: string;
};

export default function RequestFieldVisitForm({ }: { locale?: Locale }) {
	const t = useTranslations("RequestAFieldVisit");
	const { poolRequestInfo, refetch } = usePoolRequestInfo();

	const formSchema = z.object({
		fullName: z.string().min(1, t("validation.fullName.required")),
		email: z
			.string()
			.email(t("validation.email.invalid"))
			.min(1, t("validation.email.required")),
		phone: z.string().min(1, t("validation.phone.required")),
		address: z.string().min(1, t("validation.address.required")),
		message: z.string().min(1, t("validation.message.required")),
	});

	const form = useForm<RequestFieldVisitFormValues>({
		resolver: zodResolver(formSchema),
		defaultValues: {
			fullName: "",
			email: "",
			phone: "",
			address: "",
			message: "",
		},
	});

	// Pre-fill form with user data when component mounts
	useEffect(() => {
		if (poolRequestInfo) {
			const { first_name, middle_name, last_name, email, user, area_id, city_id } = poolRequestInfo;

			// Combine first, middle, and last name
			const fullName = [first_name, middle_name, last_name].filter(Boolean).join(" ");

			// Get address from city and area
			const address = area_id && city_id ? `${city_id}, ${area_id}` : "";

			form.reset({
				fullName: fullName || "",
				email: email || "",
				phone: user?.phone?.slice(3) || "",
				address: address || "",
				message: "",
			});
		}
	}, [poolRequestInfo, form]);

	const onSubmit = (data: RequestFieldVisitFormValues) => {
		console.log("submitted", data);
	};

	const renderFormField = (
		name: keyof RequestFieldVisitFormValues,
		label: string,
		type: string = "text",
		required: boolean = true
	) => {
		console.log(type);
		return (
			<FormField
				control={form.control}
				name={name}
				render={({ field }) => (
					<FormItem>
						<Label>
							<p className="text-base leading-6 text-black">
								{label}
								{required && <span className="text-[#e95757]"> *</span>}
							</p>
						</Label>
						<FormControl>
							{name === "message" ? (
								<textarea
									{...field}
									//placeholder={placeholders[0]}
									style={{ border: "1px solid #DEDEDE" }}
									className="h-[100px] w-full rounded-none border-[#DEDEDE] bg-white p-1"
								/>
							) : (
								<PlaceholdersAndVanishInput
									{...field}
									placeholders={["", "", ""]}
									onChange={field.onChange}
									className="h-[56px] w-full rounded-none border-[#DEDEDE] bg-white"
									props={{ readOnly: name === "phone" }}
								/>
							)}
						</FormControl>
						<FormMessage />
					</FormItem>
				)}
			/>
		);
	};

	return (
		<BlurFade
			duration={1.5}
			inView
			direction={"left"}
			offset={40}
			className="border border-[#DEDEDE] shadow-[0px_72px_24px_-55px_#00000026]"
		>
			<div
				className="bg-[#fafafa] p-8"
				style={{ borderBottom: "1px solid #DEDEDE" }}
			>
				<p className="mb-6 text-[40px] leading-[48px] text-custom-primary-accent">
					{t("FieldVisitService")}
				</p>
				<p className="text-justify text-[12px] leading-6 text-[#3B3B3B]">
					{t("description")}
				</p>
			</div>

			<div className="bg-[#F6F7FB] p-8">
				<Form {...form}>
					<form onSubmit={form.handleSubmit(onSubmit)} className="space-y-6">
						<div className="grid grid-cols-1 gap-4">
							{renderFormField("fullName", t("Label.FullName"))}
							{renderFormField(
								"email",
								t("Label.Email"),
								"email"
							)}
							{renderFormField("phone", t("Label.Phone"))}
							{renderFormField("address", t("Label.Address"))}
							{renderFormField(
								"message",
								t("Label.Message"),
								"text",
								true
							)}
						</div>

						<button
							type="submit"
							className="h-12 w-full bg-custom-primary-accent text-2xl font-normal text-white"
						>
							{t("Button.Submit")}
						</button>
					</form>
				</Form>
			</div>
		</BlurFade>
	);
}
